##  Quick links
  * [What is the delta between the Meta Model v4 and the Meta Model v3?](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759c5177a441014a2c5e447be725792__what_is_the_delta_between_the_meta_model_v4_and_the_meta_model_v3)
  * [Configure Workspace for Meta Model v4](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure your workspace to align with the Meta Model v4.")


Configuration basic guides:
  * [Meta Model configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements.") basics (e.g., how to create fields and relations)
  * To learn how to create a new fact sheet type, see [Creating a Custom Fact Sheet Type](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types?locale=en-US&state=PRODUCTION&version=CLOUD "Create custom fact sheet types to adjust the meta model to your organization’s needs.").
  * [How to create a Fact Sheet subtype](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types)
